"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const path = require("path");
const chalk_1 = require("chalk");
const ionic_1 = require("ionic");
const cli_framework_1 = require("@ionic/cli-framework");
const fs_1 = require("@ionic/cli-framework/utils/fs");
const format_1 = require("@ionic/cli-framework/utils/format");
const cli_utils_1 = require("@ionic/cli-utils");
const commands_1 = require("./pages/commands");
class DocsCommand extends cli_framework_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'docs',
                description: '',
            };
        });
    }
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const plugin = yield ionic_1.generateRootPlugin();
            const env = yield cli_utils_1.generateIonicEnvironment(plugin, process.argv.slice(2), process.env);
            const mdPath = path.resolve(__dirname, '..', '..', '..', '..', '..', 'docs');
            const pagesDir = path.resolve(__dirname, 'pages');
            const pages = (yield fs_1.fsReadDir(pagesDir)).filter(f => path.extname(f) === '.js').map(f => path.resolve(pagesDir, f)); // dist/docs/pages/*.js
            yield fs_1.fsMkdirp(mdPath);
            for (const p of pages) {
                const name = path.basename(p).slice(0, -path.extname(p).length);
                const render = require(p).default;
                const pageMdPath = path.resolve(mdPath, `${name}.md`);
                const renderedPage = yield render(env);
                yield fs_1.fsWriteFile(pageMdPath, renderedPage, { encoding: 'utf8' });
            }
            const commands = yield commands_1.getCommandList(env);
            const commandPromises = commands.map((cmd) => tslib_1.__awaiter(this, void 0, void 0, function* () {
                const fullName = yield commands_1.generateFullName(cmd);
                const cmdPath = path.resolve(__dirname, '..', '..', '..', '..', '..', 'docs', ...fullName.split(' '), 'index.md');
                const cmdDoc = yield commands_1.formatCommandDoc(env, cmd);
                yield fs_1.fsMkdirp(path.dirname(cmdPath));
                yield fs_1.fsWriteFile(cmdPath, cmdDoc, { encoding: 'utf8' });
            }));
            yield Promise.all(commandPromises);
            yield this.copyToIonicSite();
            env.close();
            process.stdout.write(`${chalk_1.default.green('Done.')}\n`);
        });
    }
    copyToIonicSite() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const ionicSitePath = path.resolve(__dirname, '..', '..', '..', '..', '..', '..', 'ionic-site');
            const dirData = yield fs_1.fsStat(ionicSitePath);
            if (!dirData.size) {
                // ionic-site not present
                process.stderr.write(`${chalk_1.default.red('ERROR: ionic-site repo not found')}\n`);
                return;
            }
            const srcDir = path.resolve(__dirname, '..', '..', '..', '..', '..', 'docs');
            const destDir = path.resolve(ionicSitePath, 'content', 'docs', 'cli');
            yield fs_1.copyDirectory(srcDir, destDir);
            process.stdout.write(`${chalk_1.default.green(`Docs written to ${chalk_1.default.bold(format_1.prettyPath(destDir))}.`)}\n`);
        });
    }
}
exports.DocsCommand = DocsCommand;
